@@ -1531,6 +1531,33 @@ def angle_between_vectors(v1, v2, normalize=True,
     return np.arccos(np.clip(dot if directed else np.fabs(dot), -1.0, 1.0))
 
 
+def counter_clockwise_angle_between_vectors(v1, v2, normal_vector):
+    """Returns the counter clockwise angle in radians between two vectors.
+
+    Parameters
+    ----------
+    v1 : numpy.ndarray, list[float] or tuple(float)
+        input vector.
+    v2 : numpy.ndarray, list[float] or tuple(float)
+        input vector.
+    normal_vector : numpy.ndarray, list[float] or tuple(float)
+        Base plane's normal vector.
+
+    Returns
+    -------
+    theta : float
+        counter clockwise angle between v1 and v2.
+        Return values in [0 radian, 2 * np.pi radian].
+    """
+    # https://stackoverflow.com/questions/14066933/direct-way-of-computing-clockwise-angle-between-2-vectors  # NOQA
+    det = triple_product(normal_vector, v1, v2)
+    dot = np.dot(v1, v2)
+    angle = np.arctan2(-det, -dot) + np.pi
+    if np.isclose(angle, 2 * np.pi):
+        angle = 0.0
+    return angle
+
+
 def clockwise_angle_between_vectors(v1, v2, normal_vector):
     """Returns the clockwise angle in radians between two vectors.
 
@@ -1549,7 +1576,7 @@ def clockwise_angle_between_vectors(v1, v2, normal_vector):
         clockwise angle between v1 and v2.
         Return values in [0 radian, 2 * np.pi radian].
     """
-    # https://stackoverflow.com/questions/14066933/direct-way-of-computing-clockwise-angle-between-2-vectors  # NOQA
+    normal_vector = - np.array(normal_vector)
     det = triple_product(normal_vector, v1, v2)
     dot = np.dot(v1, v2)
     angle = np.arctan2(-det, -dot) + np.pi
@@ -1678,3 +1705,7 @@ quat_from_rpy = rpy2quaternion
 rotation_matrix_from_quat = quaternion2matrix
 rpy_from_quat = quaternion2rpy
 rvec_to_quaternion = rotation_vector_to_quaternion
+
+# clockwise angle
+ccw_angle_between_vectors = counter_clockwise_angle_between_vectors
+cw_angle_between_vectors = clockwise_angle_between_vectors
